@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import Optional
 
-from ome_types.dataclasses import ome_dataclass
+from ome_types._base_type import OMEType
 
 from .light_source import LightSource
 
@@ -15,19 +15,18 @@ class Type(Enum):
     XE = "Xe"
 
 
-@ome_dataclass
-class Arc(LightSource):
+class Arc(LightSource, OMEType):
     """The Arc element is used to describe various kinds of Arc lamps - Hg, Xe, HgXe.
 
     The Power of the Arc is now stored in the LightSource.
 
     Parameters
     ----------
-    annotation_ref : AnnotationRef, optional
     id : LightSourceID
         A LightSource ID must be specified for each light source, and the
         individual light sources can be referred to by their LightSource IDs
         (eg from Channel).
+    annotation_ref : AnnotationRef, optional
     lot_number : str, optional
         The lot number of the component.
     manufacturer : str, optional
