@@ -1,7 +1,8 @@
-from dataclasses import field
 from typing import List, Optional
 
-from ome_types.dataclasses import AUTO_SEQUENCE, ome_dataclass
+from pydantic import Field
+
+from ome_types._base_type import OMEType
 
 from .annotation_ref import AnnotationRef
 from .dataset_ref import DatasetRef
@@ -10,8 +11,7 @@ from .experimenter_ref import ExperimenterRef
 from .simple_types import ProjectID
 
 
-@ome_dataclass
-class Project:
+class Project(OMEType):
     """The Project ID is required.
 
     Datasets can be grouped into projects using a many-to-many relationship. A
@@ -21,20 +21,20 @@ class Project:
 
     Parameters
     ----------
+    id : ProjectID
     annotation_ref : AnnotationRef, optional
     dataset_ref : DatasetRef, optional
     description : str, optional
         A description for the project.
     experimenter_group_ref : ExperimenterGroupRef, optional
     experimenter_ref : ExperimenterRef, optional
-    id : ProjectID
     name : str, optional
     """
 
-    annotation_ref: List[AnnotationRef] = field(default_factory=list)
-    dataset_ref: List[DatasetRef] = field(default_factory=list)
+    id: ProjectID
+    annotation_ref: List[AnnotationRef] = Field(default_factory=list)
+    dataset_ref: List[DatasetRef] = Field(default_factory=list)
     description: Optional[str] = None
     experimenter_group_ref: Optional[ExperimenterGroupRef] = None
     experimenter_ref: Optional[ExperimenterRef] = None
-    id: ProjectID = AUTO_SEQUENCE  # type: ignore
     name: Optional[str] = None
